==> OB-3.1.2.tar.gz: OB-3.1.2/ob/src/library/PolicyValidator.cpp <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#include <OB/Basic.h>
#include <OB/Except.h>
#include <OB/Template.h>
#include <OB/Declarations.h>
#include <OB/IOP.h>
#include <OB/Object.h>
#include <OB/Object.h>
#include <OB/Policy.h>
#include <OB/PolicyManager.h>
#include <OB/OBPolicies.h>

#include <PolicyValidator.h>

void
PolicyValidator::validatePolicies(const CORBA_PolicyList& l)
{
    //
    // We need to verify that the set of policies is valid.  Currently
    // this means that we may not have ProtocolPolicy and
    // ConnectionPolicy set at the same time.
    //
    CORBA_UShort hasConnectionPolicy = 0;
    CORBA_UShort hasProtocolPolicy = 0;
    OBFixSeq< CORBA_UShort > indices;

    for(CORBA_UShort i = 0; i < l.length(); ++i)
    {
        CORBA_PolicyType policyType = l[i] -> policy_type();
        if(policyType == SSL_CONNECT_POLICY)
        {
            ++hasConnectionPolicy;
            indices.append(i);
        }
        else if(policyType == OB_PROTOCOL_POLICY)
        {
            ++hasProtocolPolicy;
            indices.append(i);
        }
    }

    if(hasConnectionPolicy != 0 && hasProtocolPolicy != 0)
    {
        throw CORBA_PolicyManager::InvalidPolicies(indices);
    }
}

==> OB-4.0a2.tar.gz: OB-4.0a2/ob/src/library/PolicyValidator.cpp <==
// **********************************************************************
//
// Copyright (c) 1998
// Object-Oriented Concepts, Inc.
// Billerica, MA, USA
//
// Copyright (c) 1998
// Object-Oriented Concepts GmbH
// Ettlingen, Germany
//
// All Rights Reserved
//
// **********************************************************************

#include <OB/Basic.h>
#include <OB/Except.h>
#include <OB/Template.h>
#include <OB/OBTypes.h>
#include <OB/Declarations.h>
#include <OB/IOP.h>
#include <OB/StubImplBase.h>
#include <OB/Object.h>
#include <OB/Policy.h>
#include <OB/PolicyManager.h>
#include <OB/OBPolicies.h>

#include <PolicyValidator.h>

using namespace CORBA;

void
PolicyValidator::validatePolicies(const PolicyList& l)
{
    //
    // We need to verify that the set of policies is valid.  Currently
    // this means that we may not have ProtocolPolicy and
    // ConnectionPolicy set at the same time.
    //
    UShort hasConnectionPolicy = 0;
    UShort hasProtocolPolicy = 0;
#ifndef OB_NO_TYPE_OPT
    OB::UShortSeq indices;
#else
    PolicyManager::InvalidPolicies::_indices_seq indices;
#endif

    for(UShort i = 0; i < l.length(); ++i)
    {
        PolicyType policyType = l[i] -> policy_type();
        if(policyType == SSL::CONNECT_POLICY)
        {
            ++hasConnectionPolicy;
            indices.append(i);
        }
        else if(policyType == OB::PROTOCOL_POLICY)
        {
            ++hasProtocolPolicy;
            indices.append(i);
        }
    }

    if(hasConnectionPolicy != 0 && hasProtocolPolicy != 0)
    {
        throw PolicyManager::InvalidPolicies(indices);
    }
}
